#!/usr/bin/env bash

set -euo pipefail

. $(dirname "$0")/flux-version-check.sh

flux install \
  --network-policy=false \
  --watch-all-namespaces=true \
  --namespace=flux-system \
  --components="source-controller,kustomize-controller,helm-controller"

# get current git branch name
branch=${CI_COMMIT_REF_NAME:-}
[ -z "$branch" ] && branch=$(git rev-parse --abbrev-ref HEAD)

echo "Tracking branch $branch for https://open.greenhost.net/openappstack/openappstack flux repo"

# Create oas and oas-apps namespaces
kubectl get namespace oas 2>/dev/null || kubectl create namespace oas
kubectl get namespace oas-apps 2>/dev/null || kubectl create namespace oas-apps

# Generate oauth and SSO secrets
python "$(dirname "$0")/generate_secrets.py" single-sign-on
python "$(dirname "$0")/generate_secrets.py" oauth

# Generate secrets for monitoring
python "$(dirname "$0")/generate_secrets.py" kube-prometheus-stack
python "$(dirname "$0")/generate_secrets.py" prometheus
python "$(dirname "$0")/generate_secrets.py" alertmanager

flux create source git openappstack \
  --url=https://open.greenhost.net/openappstack/openappstack \
  --branch=$branch \
  --interval=1h

flux create kustomization openappstack \
  --source=GitRepository/openappstack \
  --path="./flux2/cluster/base" \
  --prune=true \
  --interval=1h
